GlanceTemplate enum

Widget template types.

Inheritance
Available extensions

Values

simple → const GlanceTemplate

Simple widget with title, value, and optional subtitle.

progress → const GlanceTemplate

Progress widget with circular or linear progress indicator.

list → const GlanceTemplate

List widget with scrollable items.

image → const GlanceTemplate

Image widget with title, image, and optional subtitle.

chart → const GlanceTemplate

Chart/graph widget with data points visualization.

calendar → const GlanceTemplate

Calendar/event widget with date and event list.

gauge → const GlanceTemplate

Gauge/metric widget with radial or dashboard display.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GlanceTemplate>
A constant List of the values in this enum, in order of their declaration.